function createSubmitScript(outputFilename, jobName, quotedLogFile, quotedScriptName, ...
    environmentVariables, props)
% Create a script that sets the correct environment variables and then
% executes the SLURM sbatch command.

% Copyright 2010-2014 The MathWorks, Inc.

% Open file in binary mode to make it cross-platform.
fid = fopen(outputFilename, 'w');
if fid < 0
    error('parallelexamples:GenericSLURM:FileError', ...
        'Failed to open file %s for writing', outputFilename);
end

getSubmitString = @profiles.umd.deepthought2.getSubmitString;

% Specify Shell to use
fprintf(fid, '#!/bin/sh\n');

% MATLAB uses a triad license server; however, MDCS is going to use a local 
% license manager.  Therefore, we'll pass MLM_LICENSE_FILE along with the
% job and point to a specific location for just MDCS
mroot = strsplit(props.MatlabExecutable,'bin');
mroot = mroot{1};
licfile = [mroot 'licenses/mdcs/mdcs.lic'];
environmentVariables(end+1,:) = {'MLM_LICENSE_FILE',licfile};

% Write the commands to set and export environment variables
for ii = 1:size(environmentVariables, 1)
    fprintf(fid, '%s=%s\n', environmentVariables{ii,1}, environmentVariables{ii,2});
    fprintf(fid, 'export %s\n', environmentVariables{ii,1});
end

% Generate the command to run and write it.
commandToRun = getSubmitString(jobName, quotedLogFile, quotedScriptName, props);
fprintf(fid, '%s\n', commandToRun);

% Close the file
fclose(fid);
