function asa = getAdditionalSubmitArguments(props)

% http://www.glue.umd.edu/hpcc/help/jobs.html

% MW: To specify --exclusive/--share, use UserDefinedOptions.

% Copyright 2010-2014 The MathWorks, Inc.

asa = '';

[~,flag] = strtok(props.MatlabArguments,'p');
if strcmp(flag,'parallel')
    w = props.NumberOfTasks;
else
    w = 1;
end

asa = sprintf('%s --ntasks %d',asa,w);


%% REQUIRED

%% OPTIONAL

% Walltime
wt = ClusterInfo.getWallTime();
if isempty(wt)==false
    asa = [asa ' -t ' wt];
end

% Memory per cpu
% MW: Should we also support (--mem memory per node)?
mu = ClusterInfo.getMemUsage();
if isempty(mu)==false
    % Per CPU (in MB)
    asa = [asa ' --mem-per-cpu=' mu];
end

% Specify Project
pn = ClusterInfo.getProjectName();
if isempty(pn)==false
    asa = [asa ' -A ' pn];
end

% Partition
qn = ClusterInfo.getQueueName();
if isempty(qn)==false
    asa = [asa ' -p ' qn];
end

% GPUs
gpu = ClusterInfo.getUseGpu();
if gpu==true
    ngpus = ClusterInfo.getGpusPerNode();
    if isempty(ngpus)==false
        cnt = sprintf(':%d',ngpus);
    else
        cnt = '';
    end
    asa = sprintf('%s --gres=gpu%s',asa,cnt);
end

% Check if user wants email updates
ea = ClusterInfo.getEmailAddress();
if isempty(ea)==false
    % User wants to be emailed the job status
    asa = [asa ' --mail-type=ALL --mail-user=' ea];
end

% Check if user is using a reservation
res = ClusterInfo.getReservation();
if isempty(res)==false
    asa = [asa ' --reservation ' res];
end

% Check Data Parallelism
dp = ClusterInfo.getDataParallelism();
if isempty(dp)==false
    % TODO
end

% Every job is going to require a certain number of MDCS licenses
% Specification of MDCS licenses which must be allocated to this
% job.  The /etc/slurm/slurm.conf file must list
%
%   # MDCS licenses
%   Licenses=mdcs:600
%
asa = sprintf('%s --licenses=mdcs:%d',asa,w);

% Catch-all
udo = ClusterInfo.getUserDefinedOptions();
if isempty(udo)==false
    asa = [asa ' ' udo];
end

asa = strtrim(asa);
